pub struct ConstantSource(pub f64);Expand description
A constant source that always returns the same value.
This is the simplest source type - it always produces the same value regardless of context.
Examples
use zzstat::source::{ConstantSource, StatSource};
use zzstat::{StatId, StatContext};
let source = ConstantSource(100.0);
let context = StatContext::new();
let stat_id = StatId::from_str("HP");
assert_eq!(source.get_value(&stat_id, &context), 100.0);Tuple Fields
0: f64Trait Implementations
Sourceimpl Clone for ConstantSource
impl Clone for ConstantSource
Sourcefn clone(&self) -> ConstantSource
fn clone(&self) -> ConstantSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConstantSource
impl Debug for ConstantSource
Sourceimpl StatSource for ConstantSource
impl StatSource for ConstantSource