pub struct StatId(/* private fields */);Expand description
Interned string identifier for stats.
Uses Arc<str> for memory efficiency and fast comparison.
Multiple StatId instances with the same string content share the same
underlying allocation.
Examples
use zzstat::StatId;
let hp = StatId::from("HP");
let atk = StatId::from("ATK");
// Can be created from string slices or owned strings
let hp2: StatId = "HP".into();
let hp3: StatId = String::from("HP").into();
assert_eq!(hp, hp2);
assert_eq!(hp, hp3);Implementations